# Enabling Discovered Flows
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#overview)
  * [How Flow Discovery Works](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#how-flow-discovery-works)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#prerequisites)
  * [Step 1: Update the SAP Cloud ALM Service Key Configuration](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#step-1:-update-the-sap-cloud-alm-service-key-configuration)
  * [Step 2: Enable Discovered Flows in SAP LeanIX](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#step-2:-enable-discovered-flows-in-sap-leanix)
  * [Step 3: Verify Sync and View Discovered Items](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#step-3:-verify-sync-and-view-discovered-items)
  * [Understanding Discovered Flow Items](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#understanding-discovered-flow-items)
  * [Working with Discovered Flows](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#working-with-discovered-flows)
  * [Troubleshooting](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows#troubleshooting)


Discovered flows in SAP Cloud ALM enable automatic identification and visualization of real integration flows between SAP systems, supporting integration mapping, dependency analysis, and interface documentation. This feature helps organizations gain visibility into active system communications and streamline interface management.
